=======
Credits
=======

Development TEAM
----------------

* Miquel Duran Frigola <miquel.duran@irbbarcelona.org>
* Oriol Guitart <oriol.guitart@irbbarcelona.org>
* Martino Bertoni <martino.bertoni@irbbarcelona.org>
* Pau Badia <pau.badia@irbbarcelona.org>
* Nicolas Soler <nicolas.soler@irbbarcelona.org>


Contributors
------------

* Adria Fernandez <adria.fernandez@irbbarcelona.org>
* Lidia Mateo <lidia.mateo@irbbarcelona.org>
* David Amat <david.amat@irbbarcelona.org>
* Alejandro Castrelo <alejandro.castrelo@irbbarcelona.org>
* Modesto Orozco <modesto.orozco.ruiz@irbbarcelona.org>
* Aleix Gimeno <aleix.gimeno@irbbarcelona.org>
* Paula Torren <paula.torren@irbbarcelona.org>
* Elena Pareja <elena.pareja@irbbarcelona.org>
* Roger Compte <roger.compte@irbbarcelona.org>
